@@ -9,5 +9,8 @@ fn main() {
     for frame in decoder.into_iter() {
         assert_eq!(frame.dimensions(), (400, 400));
         assert_eq!(frame.data().len(), 400 * 400 * 4); // w * h * rgba
+
+        #[cfg(features = "image")]
+        assert_eq!(frame.into_image().unwrap().dimensions(), (400, 400));
     }
 }
